==> ejc-settlementmanage-impl-3.0.0-20230322.091825-186-sources.jar: com/ejianc/business/settlementmanage/bean/SettlementBookMaterialDetailEntity.java <==
package com.ejianc.business.settlementmanage.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 工程分包结算书子表-支出明细-材料节超分析表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_settlementmanage_settlement_book_material")
public class SettlementBookMaterialDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="bill_code")
    private java.lang.String billCodeB; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="sort")
    private java.lang.Long sort; // 序号
    @TableField(value="material_name")
    private java.lang.String materialNameB; // 材料名称
    @TableField(value="units")
    private java.lang.String unitsB; // 单位
    @TableField(value="dosage_collar")
    private java.lang.Long dosageCollarB; // 领用量
    @TableField(value="settlement_num")
    private java.lang.Long settlementNumB; // 结算量
    @TableField(value="section_num")
    private java.lang.Long sectionNumB; // 节超量
    @TableField(value="extax_purchasingprice")
    private java.math.BigDecimal extaxPurchasingpriceB; // 采购单价(除税)
    @TableField(value="intax_purchasingprice")
    private java.math.BigDecimal intaxPurchasingprice; // 采购单价(含税)
    @TableField(value="extax_sectionprice")
    private java.math.BigDecimal extaxSectionpriceB; // 节超金额(除税)
    @TableField(value="intax_sectionprice")
    private java.math.BigDecimal intaxSectionprice; // 节超金额(含税)
    @TableField(value="section")
    private java.lang.String sectionB; // 区段
    @TableField(value="cum_extax_sectionprice")
    private java.math.BigDecimal cumExtaxSectionprice; // 累计节超金额(除税)
    @TableField(value="cum_intax_sectionprice")
    private java.math.BigDecimal cumIntaxSectionprice; // 累计节超金额(含税)
    @TableField(value="cur_extax_sectionprice")
    private java.math.BigDecimal curExtaxSectionprice; // 本期节超金额(除税)
    @TableField(value="cur_intax_sectionprice")
    private java.math.BigDecimal curIntaxSectionprice; // 本期节超金额(含税)


    public Long getMid() {
        return mid;
    }

    public void setMid(Long mid) {
        this.mid = mid;
    }

    public String getBillCodeB() {
        return billCodeB;
    }

    public void setBillCodeB(String billCodeB) {
        this.billCodeB = billCodeB;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Long getSort() {
        return sort;
    }

    public void setSort(Long sort) {
        this.sort = sort;
    }

    public String getMaterialNameB() {
        return materialNameB;
    }

    public void setMaterialNameB(String materialNameB) {
        this.materialNameB = materialNameB;
    }

    public String getUnitsB() {
        return unitsB;
    }

    public void setUnitsB(String unitsB) {
        this.unitsB = unitsB;
    }

    public Long getDosageCollarB() {
        return dosageCollarB;
    }

    public void setDosageCollarB(Long dosageCollarB) {
        this.dosageCollarB = dosageCollarB;
    }

    public Long getSettlementNumB() {
        return settlementNumB;
    }

    public void setSettlementNumB(Long settlementNumB) {
        this.settlementNumB = settlementNumB;
    }

    public Long getSectionNumB() {
        return sectionNumB;
    }

    public void setSectionNumB(Long sectionNumB) {
        this.sectionNumB = sectionNumB;
    }

    public BigDecimal getExtaxPurchasingpriceB() {
        return extaxPurchasingpriceB;
    }

    public void setExtaxPurchasingpriceB(BigDecimal extaxPurchasingpriceB) {
        this.extaxPurchasingpriceB = extaxPurchasingpriceB;
    }

    public BigDecimal getIntaxPurchasingprice() {
        return intaxPurchasingprice;
    }

    public void setIntaxPurchasingprice(BigDecimal intaxPurchasingprice) {
        this.intaxPurchasingprice = intaxPurchasingprice;
    }

    public BigDecimal getExtaxSectionpriceB() {
        return extaxSectionpriceB;
    }

    public void setExtaxSectionpriceB(BigDecimal extaxSectionpriceB) {
        this.extaxSectionpriceB = extaxSectionpriceB;
    }

    public BigDecimal getIntaxSectionprice() {
        return intaxSectionprice;
    }

    public void setIntaxSectionprice(BigDecimal intaxSectionprice) {
        this.intaxSectionprice = intaxSectionprice;
    }

    public String getSectionB() {
        return sectionB;
    }

    public void setSectionB(String sectionB) {
        this.sectionB = sectionB;
    }

    public BigDecimal getCumExtaxSectionprice() {
        return cumExtaxSectionprice;
    }

    public void setCumExtaxSectionprice(BigDecimal cumExtaxSectionprice) {
        this.cumExtaxSectionprice = cumExtaxSectionprice;
    }

    public BigDecimal getCumIntaxSectionprice() {
        return cumIntaxSectionprice;
    }

    public void setCumIntaxSectionprice(BigDecimal cumIntaxSectionprice) {
        this.cumIntaxSectionprice = cumIntaxSectionprice;
    }

    public BigDecimal getCurExtaxSectionprice() {
        return curExtaxSectionprice;
    }

    public void setCurExtaxSectionprice(BigDecimal curExtaxSectionprice) {
        this.curExtaxSectionprice = curExtaxSectionprice;
    }

    public BigDecimal getCurIntaxSectionprice() {
        return curIntaxSectionprice;
    }

    public void setCurIntaxSectionprice(BigDecimal curIntaxSectionprice) {
        this.curIntaxSectionprice = curIntaxSectionprice;
    }
}

==> ejc-settlementmanage-impl-3.0.0-20230525.080453-250-sources.jar: com/ejianc/business/settlementmanage/bean/SettlementBookMaterialDetailEntity.java <==
package com.ejianc.business.settlementmanage.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 工程分包结算书子表-支出明细-材料节超分析表
 *
 * @author generator
 *
 */
 @TableName("ejc_settlementmanage_settlement_book_material")
public class SettlementBookMaterialDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="sort")
    private java.lang.Long sort; // 序号
    @TableField(value="material_code")
    private String materialCode; // 材料编码
    @TableField(value="material_name")
    private java.lang.String materialName; // 材料名称
    @TableField(value="units")
    private java.lang.String units; // 单位
    @TableField(value="spec")
    private String spec; // 规格及特征
    @TableField(value="dosage_collar")
    private BigDecimal dosageCollar; // 预算数量
    @TableField(value="settlement_num")
    private BigDecimal settlementNum; // 实际消耗数量
    @TableField(value="section_num")
    private BigDecimal sectionNum; // 节超量
    @TableField(value="extax_purchasingprice")
    private java.math.BigDecimal extaxPurchasingprice; // 采购单价(除税)
    @TableField(value="intax_purchasingprice")
    private java.math.BigDecimal intaxPurchasingprice; // 采购单价(含税)
    @TableField(value="extax_sectionprice")
    private java.math.BigDecimal extaxSectionprice; // 节超金额(除税)
    @TableField(value="intax_sectionprice")
    private java.math.BigDecimal intaxSectionprice; // 节超金额(含税)
    @TableField(value="section")
    private java.lang.String sectionB; // 区段
    @TableField(value="cum_extax_sectionprice")
    private java.math.BigDecimal cumExtaxSectionprice; // 累计节超金额(除税)
    @TableField(value="cum_intax_sectionprice")
    private java.math.BigDecimal cumIntaxSectionprice; // 累计节超金额(含税)
    @TableField(value="cur_extax_sectionprice")
    private java.math.BigDecimal curExtaxSectionprice; // 本期节超金额(除税)
    @TableField(value="cur_intax_sectionprice")
    private java.math.BigDecimal curIntaxSectionprice; // 本期节超金额(含税)
    @TableField(value="is_midd_id")
    private java.lang.Long isMiddId; // 回写状态id

    public Long getIsMiddId() {
        return isMiddId;
    }

    public void setIsMiddId(Long isMiddId) {
        this.isMiddId = isMiddId;
    }

    public Long getMid() {
        return mid;
    }

    public void setMid(Long mid) {
        this.mid = mid;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Long getSort() {
        return sort;
    }

    public void setSort(Long sort) {
        this.sort = sort;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public String getUnits() {
        return units;
    }

    public void setUnits(String units) {
        this.units = units;
    }

    public BigDecimal getDosageCollar() {
        return dosageCollar;
    }

    public void setDosageCollar(BigDecimal dosageCollar) {
        this.dosageCollar = dosageCollar;
    }

    public BigDecimal getSettlementNum() {
        return settlementNum;
    }

    public void setSettlementNum(BigDecimal settlementNum) {
        this.settlementNum = settlementNum;
    }

    public BigDecimal getSectionNum() {
        return sectionNum;
    }

    public void setSectionNum(BigDecimal sectionNum) {
        this.sectionNum = sectionNum;
    }

    public BigDecimal getExtaxPurchasingprice() {
        return extaxPurchasingprice;
    }

    public void setExtaxPurchasingprice(BigDecimal extaxPurchasingprice) {
        this.extaxPurchasingprice = extaxPurchasingprice;
    }

    public BigDecimal getIntaxPurchasingprice() {
        return intaxPurchasingprice;
    }

    public void setIntaxPurchasingprice(BigDecimal intaxPurchasingprice) {
        this.intaxPurchasingprice = intaxPurchasingprice;
    }

    public BigDecimal getExtaxSectionprice() {
        return extaxSectionprice;
    }

    public void setExtaxSectionprice(BigDecimal extaxSectionprice) {
        this.extaxSectionprice = extaxSectionprice;
    }

    public BigDecimal getIntaxSectionprice() {
        return intaxSectionprice;
    }

    public void setIntaxSectionprice(BigDecimal intaxSectionprice) {
        this.intaxSectionprice = intaxSectionprice;
    }

    public String getSectionB() {
        return sectionB;
    }

    public void setSectionB(String sectionB) {
        this.sectionB = sectionB;
    }

    public BigDecimal getCumExtaxSectionprice() {
        return cumExtaxSectionprice;
    }

    public void setCumExtaxSectionprice(BigDecimal cumExtaxSectionprice) {
        this.cumExtaxSectionprice = cumExtaxSectionprice;
    }

    public BigDecimal getCumIntaxSectionprice() {
        return cumIntaxSectionprice;
    }

    public void setCumIntaxSectionprice(BigDecimal cumIntaxSectionprice) {
        this.cumIntaxSectionprice = cumIntaxSectionprice;
    }

    public BigDecimal getCurExtaxSectionprice() {
        return curExtaxSectionprice;
    }

    public void setCurExtaxSectionprice(BigDecimal curExtaxSectionprice) {
        this.curExtaxSectionprice = curExtaxSectionprice;
    }

    public BigDecimal getCurIntaxSectionprice() {
        return curIntaxSectionprice;
    }

    public void setCurIntaxSectionprice(BigDecimal curIntaxSectionprice) {
        this.curIntaxSectionprice = curIntaxSectionprice;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
}
